==> ttyrpld-2.03.tar.bz2: ttyrpld-2.03/doc/desc.php <==
<?php include_once("_header.php"); ?>
  <tr>

    <td align="right" valign="top"
    class="section"><b>Description&nbsp;&gt;</b></td>

    <td valign="top">

      <p class="block"><i>ttyrpld</i> is a Kernel-based keylogger and
      screenlogger for Linux, FreeBSD and OpenBSD, and includes a real-time,
      tail-following log analyzer. It supports most tty types, including
      <tt>vc</tt>, bsd and unix98-style <tt>pty</tt>s (xterm/ssh), serial,
      isdn, etc. Being implemented within the Kernel makes it unavoidable for
      the default user. Another benefit is that it runs with no overhead if the
      user-space logging daemon is not active.</p>

    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>

    <td align="right" valign="top" class="section"><b>Categorization<br />
    (SF-style)&nbsp;&gt;</b></td>

    <td valign="top">
      <div class="indent"><table border="1" class="sBorder">
        <tr>
          <td>Super Short Description:</td>
          <td>Incircumventable Kernel-based tty keylogger and screenlogger for
            Linux/FreeBSD/OpenBSD with real-time and tail-follow log analyzer.
            Supports vc, bsd/unix98 pty (xterm/ssh), serial, isdn, etc.</td>
        </tr>
        <tr>
          <td>Development Status:</td>
          <td>Linux: 6 - Mature<br />
            FreeBSD: 5 - Production/Stable<br />
            OpenBSD: 4 - Beta</td>
        </tr>
        <tr>
          <td>Intended Audience:</td>
          <td>Advanced End Users, Developers, System Administrators,
            Telecommunications Industry, Information Technology</td>
        </tr>
        <tr>
          <td>License:</td>
          <td>GNU General Public License (GPL) version 2</td>
        </tr>
        <tr>
          <td>Languages (natural first):</td>
          <td>English, Persian-Farsi (<tt>ar_IQ</tt>), German (<tt>de</tt>),
            Spanish (<tt>es</tt>), French (<tt>fr</tt>), Italian (<tt>it</tt>),
            Norwegian-Bokmål (<tt>nb</tt>), Netherlandish (<tt>nl</tt>),
            Swedish (<tt>sv</tt>)</td>
        </tr>
        <tr>
          <td>Operating System:</td>
          <td>Linux 2.4, 2.6, FreeBSD 5.3, OpenBSD 3.6</td>
        </tr>
        <tr>
          <td>Programming Language:</td>
          <td>C/GNU89</td>
        </tr>
        <tr>
          <td>Topic:</td>
          <td>Systems Administration, Security</td>
        </tr>
        <tr>
          <td>Environment:</td>
          <td>Non-interactive (Daemon), Command-line, Console/Terminal</td>
        </tr>
      </table></div>
    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>

    <td align="right" valign="top" class="section"><b>Technical
    Aspects&nbsp;&gt;</b></td>

    <td valign="top">

      <p><i>... which cause it to differ from existing solutions:</i></p>

      <p class="block">Most other solutions deploy the logging completely in
      userspace and make it dependent on the user to activate the logging. 
      Definitely, an intruder does not start e.g. <tt>/usr/bin/script</tt>
      voluntarily. I have only seen few other kernel-based loggers. One of them
      is sadly outdated, others query the X86 keyboard driver (very unportable,
      and does not work with exotic keyboards, not to mention network traffic)
      instead of tty lines, and some only allow ghost-network transfer. To sum
      it up, there exist only very few solutions to which I could compare.</p>

      <p class="block">Only the FreeBSD snooper <i>watch</i>, which operates on
      the <tt>/dev/snp*</tt> devices, can be taken for a comparison. However,
      it can only do the interactive live feed mode, no logging is possible for
      later replay, line and time stamps are missing.</p>

    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>

    <td align="right" valign="top"
    class="section"><b>Components&nbsp;&gt;</b></td>

    <td valign="top">

      <p class="block">This kit (<i>ttyrpld</i>) consists of four
      components:</p>

      <p class="block"><i>kpatch</i>: The Kernel patch adds a few lines to
      provide the <i>rpldev</i> extension hooks, which (any) module can then
      get onto. The system was not directly written for black-hats who want to
      leave as little traces as possible, keep in mind. <tt>:-)</tt></p>

      <p class="block"><i>rpldev</i>: The Kernel module is responsible for
      grabbing the data off the tty line and providing a character device for
      the user-space logging daemon. Data grabbed of the tty is directly passed
      to the overlying daemons, so with the correct terminal settings you can
      get a 1:1 replay.</p>

      <p class="block">For systems where module loading is not possible
      (OpenBSD for example), these two components are integrated into the
      kpatch.</p>

      <p class="block"><i>rpld</i>: Having received the captured data, the
      logging daemon can store them in any format and/or facility, with or
      without compression, just as it likes, for this happens in user-space and
      thus you have all the fluffy libraries available. (That would not be the
      case from Kernel space.)</p>

      <p class="block"><i>ttyreplay</i>: real-time log analyzer. Think of it
      like <a href="http://mplayerhq.hu/" target="_blank">mplayer</a>.</p>

    </td>
  </tr>
<?php include_once("_footer.php"); ?>

==> ttyrpld-2.10.tar.bz2: ttyrpld-2.10/doc/desc.php <==
<?php include_once("_header.php"); ?>
  <tr>

    <td align="right" valign="top"
    class="section"><b>Description&nbsp;&gt;</b></td>

    <td valign="top">

      <p class="block"><i>ttyrpld</i> is a Kernel-based keylogger and
      screenlogger for Linux, FreeBSD and OpenBSD, and includes a real-time,
      tail-following log analyzer. It supports most tty types, including
      <tt>vc</tt>, bsd and unix98-style <tt>pty</tt>s (xterm/ssh), serial,
      isdn, etc. Being implemented within the Kernel makes it unavoidable for
      the default user. Another benefit is that it runs with no overhead if the
      user-space logging daemon is not active.</p>

    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>

    <td align="right" valign="top" class="section"><b>Categorization<br />
    (SF-style)&nbsp;&gt;</b></td>

    <td valign="top">
      <div class="indent"><table border="1" class="sBorder">
        <tr>
          <td>Super Short Description:</td>
          <td>Incircumventable Kernel-based tty keylogger and screenlogger for
            Linux/FreeBSD/OpenBSD with real-time and tail-follow log analyzer.
            Supports vc, bsd/unix98 pty (xterm/ssh), serial, isdn, etc.</td>
        </tr>
        <tr>
          <td>Development Status:</td>
          <td>6 - Mature</td>
        </tr>
        <tr>
          <td>Intended Audience:</td>
          <td>Advanced End Users, Developers, System Administrators,
            Telecommunications Industry, Information Technology</td>
        </tr>
        <tr>
          <td>License:</td>
          <td>GNU General Public License (GPL) version 2</td>
        </tr>
        <tr>
          <td>Languages (natural first):</td>
          <td>English, Persian-Farsi (<tt>ar_IQ</tt>), German (<tt>de</tt>),
            Spanish (<tt>es</tt>), French (<tt>fr</tt>), Italian (<tt>it</tt>),
            Norwegian-Bokmål (<tt>nb</tt>), Netherlandish (<tt>nl</tt>),
            Swedish (<tt>sv</tt>)</td>
        </tr>
        <tr>
          <td>Operating Systems:</td>
          <td>Linux 2.6, FreeBSD 6.0, OpenBSD 3.8</td>
        </tr>
        <tr>
          <td>Programming Language:</td>
          <td>C/GNU89</td>
        </tr>
        <tr>
          <td>Topic:</td>
          <td>Systems Administration, Security</td>
        </tr>
        <tr>
          <td>Environment:</td>
          <td>Non-interactive (Daemon), Command-line, Console/Terminal</td>
        </tr>
      </table></div>
    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>

    <td align="right" valign="top" class="section"><b>Technical
    Aspects&nbsp;&gt;</b></td>

    <td valign="top">

      <p><i>... which cause it to differ from existing solutions:</i></p>

      <p class="block">Most other solutions deploy the logging completely in
      userspace and make it dependent on the user to activate the logging. 
      Definitely, an intruder does not start e.g. <tt>/usr/bin/script</tt>
      voluntarily. I have only seen few other kernel-based loggers. One of them
      is sadly outdated, others query the X86 keyboard driver (very unportable,
      and does not work with exotic keyboards, not to mention network traffic)
      instead of tty lines, and some only allow ghost-network transfer. To sum
      it up, there exist only very few solutions to which I could compare.</p>

      <p class="block">Only the FreeBSD snooper <i>watch</i>, which operates on
      the <tt>/dev/snp*</tt> devices, can be taken for a comparison. However,
      it can only do the interactive live feed mode, no logging is possible for
      later replay, line and time stamps are missing.</p>

    </td>
  </tr>
  <tr>
    <td>&nbsp;</td>
  </tr>
  <tr>

    <td align="right" valign="top"
    class="section"><b>Components&nbsp;&gt;</b></td>

    <td valign="top">

      <p class="block">This kit (<i>ttyrpld</i>) consists of four
      components:</p>

      <p class="block"><i>kpatch</i>: The Kernel patch adds a few lines to
      provide the <i>rpldev</i> extension hooks, which (any) module can then
      get onto. The system was not directly written for black-hats who want to
      leave as little traces as possible, keep in mind. <tt>:-)</tt></p>

      <p class="block"><i>rpldev</i>: The Kernel module is responsible for
      grabbing the data off the tty line and providing a character device for
      the user-space logging daemon. Data grabbed of the tty is directly passed
      to the overlying daemons, so with the correct terminal settings you can
      get a 1:1 replay.</p>

      <p class="block">For systems where module loading is not possible
      (OpenBSD for example), these two components are integrated into the
      kpatch.</p>

      <p class="block"><i>rpld</i>: Having received the captured data, the
      logging daemon can store them in any format and/or facility, with or
      without compression, just as it likes, for this happens in user-space and
      thus you have all the fluffy libraries available. (That would not be the
      case from Kernel space.)</p>

      <p class="block"><i>ttyreplay</i>: real-time log analyzer. Think of it
      like <a href="http://mplayerhq.hu/" target="_blank">mplayer</a>.</p>

    </td>
  </tr>
<?php include_once("_footer.php"); ?>
